mapping = {
    'status': 'hudson.views.StatusColumn',
    'weather': 'hudson.views.WeatherColumn',
    'job': 'hudson.views.JobColumn',
    'last_success': 'hudson.views.LastSuccessColumn',
    'last_failure': 'hudson.views.LastFailureColumn',
    'last_duration': 'hudson.views.LastDurationColumn',
    'build_button': 'hudson.views.BuildButtonColumn'
    }
